function pipeline_b = psom_bundle_cleanup(pipeline,name)
% Bundle all the clean-up jobs of a pipeline into a separate "job".
%
% SYNTAX:
% PIPELINE_B = PSOM_BUNDLE_CLEANUP(PIPELINE,NAME)
%
% _________________________________________________________________________
% INPUTS:
%
% PIPELINE
%   (structure) A PSOM pipeline structure.
% 
% NAME
%   (string) the name of the bundled clean-up job.
%
% _________________________________________________________________________
% OUTPUTS
%
% PIPELINE_B
%    (structure) same as PIPELINE, except that all the clean-up jobs are 
%    bundled up into a single job called NAME.  
% 
% _________________________________________________________________________
% COMMENTS
%
% Clean-up jobs are defined as jobs associated with the "psom_clean(files_clean)"
% command. Those are generally generated by the PSOM_ADD_CLEAN command.
%
% Copyright (c) Pierre Bellec
% Research Centre of the Montreal Geriatric Institute
% & Department of Computer Science and Operations Research
% University of Montreal, Québec, Canada, 2012
% Maintainer : pierre.bellec@criugm.qc.ca
% See licensing information in the code.
% Keywords : pipeline, dependencies

% Permission is hereby granted, free of charge, to any person obtaining a copy
% of this software and associated documentation files (the "Software"), to deal
% in the Software without restriction, including without limitation the rights
% to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
% copies of the Software, and to permit persons to whom the Software is
% furnished to do so, subject to the following conditions:
%
% The above copyright notice and this permission notice shall be included in
% all copies or substantial portions of the Software.
%
% THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
% IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
% FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
% AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
% LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
% OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
% THE SOFTWARE.

%% SYNTAX
if nargin<2
    error('SYNTAX: PIPELINE_B = PSOM_BUNDLE_CLEANUP(PIPELINE,NAME). Type ''help psom_bundle_cleanup'' for more info.')
end

list_jobs = fieldnames(pipeline);
nb_jobs = length(list_jobs);
cleanup.command = 'psom_clean(files_clean)';
cleanup.files_clean = struct();
for num_j = 1:nb_jobs
    if strcmp(pipeline.(list_jobs{num_j}).command,cleanup.command)&&isfield(pipeline.(list_jobs{num_j}),'files_clean')
        cleanup.files_clean.(list_jobs{num_j}) = pipeline.(list_jobs{num_j}).files_clean;
    end
end

if ~isempty(fieldnames(cleanup.files_clean))
    pipeline_b = rmfield(pipeline,fieldnames(cleanup.files_clean));
    cleanup.files_clean = psom_files2cell(cleanup.files_clean);
    pipeline_b.(name) = cleanup;
else
    pipeline_b = pipeline;
end